#!/bin/ksh
#> This script will install Prospect 8.0 / LucentQAS RP1.0 
#> for IZ43242 - Data availability graph do not reflect availability of data in traffic tables. 
#> Usage: install.sh {-help|-install|-uninstall}
#

InstallFileset='
vendor/Lucent/QAS/missingData/wm_AvailData_pkg.sql
'

########################################################
# set paths and files

RELEASE="1.0.1.0.1.1"
SourceDir="${FLEXPM_HOME}/patches/${RELEASE}"
SourceDir1="${FLEXPM_HOME}/patches/${RELEASE}/LucQAS"
BackupDir="${FLEXPM_HOME}/patches/${RELEASE}/backup/"

########################################################

### give help
  ToolName=`basename $0`
  runTime=`date '+%Y%m%d%H%M'`
  case $1 in
  -help|-usage)
    echo "${ToolName} usage information -- " 1>&2
    grep "^#> " $0 1>&2
    grep "^#>  \"" $0 1>&2
    exit 2
    ;;
  esac

# Check env settings

  if [ $# -ne 1 ]; then
    echo "Usage $0 {-help | -install | -uninstall}"
    exit;
  fi

  echo "Checking environment....."
  if ! [[ -d ${FLEXPM_HOME} ]]; then
    echo "Env variable FLEXPM_HOME must be set to appropriate dir before installation."
    exit;
  fi

  if ! [[ -d ${LucQAS_HOME} ]]; then
    echo "Env variable LucQAS_HOME must be set to appropriate dir before installation."
    exit;
  fi

  if [[ -z ${DB_CONNECT} ]]; then
     echo "Env variable DB_CONNECT must be set to approriate database connection values."
     exit;
  fi
 


  
cd $SourceDir
# Source and destination directories

  case $1 in
  -install)
    echo "Installing patch..."
  if [[ -d ${BackupDir} ]]; then
           echo "Patch ${VERSION} may have been already applied. Aborting patch installation.\n"
           exit
  else
           mkdir -p -m 744 ${BackupDir}
  fi
    # Updating the LucQAS.build file
    chmod +w ${SourceDir}/LucQAS.build

    echo "Registration of ${RELEASE} started."
    chmod +x $FLEXPM_HOME/pm/adm/register
    register start ${SourceDir}/LucQAS.build
    [[ $? -ne 0 ]] && exit 1;


    
    echo "Files to be updated/added ..."

    cd $SourceDir1
   touch ${BackupDir}/backup_source.tar

    for f in ${InstallFileset}
    do
        echo "${LucQAS_HOME}/${f}"
        if [[ -a ${LucQAS_HOME}/${f} ]]; then
        # permissions
        chmod u+w ${LucQAS_HOME}/${f}
		
        # Keep appeding files to the backup tarball 
        tar -rf ${BackupDir}/backup_source.tar $LucQAS_HOME/${f}

        fi
        # install files
	cp -pf ${SourceDir1}/${f} ${LucQAS_HOME}/${f}
		
	# permissions
	chmod u+x ${LucQAS_HOME}/${f}

        # Compile the package
	echo "Compiling ${LucQAS_HOME}/${f}..."
	echo "@${LucQAS_HOME}/${f};\nExit;" | sqlplus ${DB_CONNECT} 


    done
 
    register complete ${SourceDir}/LucQAS.build

    echo "Installation completed successfully."
    ;;

  -uninstall)

  echo ""
    echo "+ Attempting to restore backup files ..."

    cd ${FLEXPM_HOME}

    if [[ -f ${BackupDir}/backup_source.tar ]];
    then
      echo "+ Found backup files... restoring ..."
      for file in `tar -tf ${BackupDir}/backup_source.tar`
      do
         if [ -f $file ]
         then
           chmod +w $file
         fi
      done

      tar -xvf ${BackupDir}/backup_source.tar

      for f in ${InstallFileset}
      do
          # permissions
	  #chmod u-w ${LucQAS_HOME}/${f}
	  chmod u+x ${LucQAS_HOME}/${f}

	  # Compile the package
	  echo "Compiling ${LucQAS_HOME}/${f}..."
	  echo "@${LucQAS_HOME}/${f};\nExit;" | sqlplus ${DB_CONNECT}
      done

    # Remove the component registration for this patch
      COMP_REG=`show_installed | grep 'rev 1.0.1.0.1 b1'`
      if [[ ! -z ${COMP_REG} ]]; then
sq1="select component_version_id from component_version where revision = '1.0.1.0.1' and component_id in (select component_id from component where component_name in ('LucQAS'))"
sq3="delete component_history where component_version_id in ( $sq1 )"
sq4="delete component_installed where component_version_id in ( $sq1 )"
sq5="delete component_version where component_version_id in ( $sq1 )"
sqlplus -s /nolog <<EOF
connect $DBUSER/$DBPASSWD@$DBSID
${sq3};
${sq4};
${sq5};
exit;
EOF
      fi
    else
      echo "+ Backup files not found... exiting..."
      exit;
    fi
    cd ${START_DIR}

  echo "End: " `date`

  echo "Un-installation Complete."
    break
    ;; 

  * )
    echo "Unknown option"
    echo "Usage: install.sh {-help|-install|-uninstall}"
    ;;
  esac
