-- This script is to patch back the missing Data Available records
-- to synchronize with records in the traffic tables
set serveroutput on size 50000
@patchMissingDA.sql

DECLARE
  gTimeSlice        Integer;
  gTimeUnit         Integer := 60;
  v_count_da        Integer;
  v_count_tf        Integer;
  v_count_update    Integer;
  v_TimeStamp_s     Date;
  v_TimeStamp_e     Date;
  v_traffic_table   VARCHAR2(100);
  v_Filetype        wm_file_control.file_type%TYPE;
  v_Filetype_ID     wm_file_control.file_type_id%TYPE;
  v_Entity_ID       wm_file_control.entity_id%TYPE;
  v_MergeStmt       LONG;
  v_SelectTF        VARCHAR2(100);
  v_SelectDA        VARCHAR2(250);
  TYPE ref_cur_type IS REF CURSOR;
  lv_c2             ref_cur_type;

  BEGIN
    
    gTimeSlice    := dataAvail.get_property('TimeSlices'); 
    v_TimeStamp_s := to_date('&1', 'YYYYMMDD'); 
    v_TimeStamp_e := to_date('&2', 'YYYYMMDD');    

    --dbms_output.put_line('v_TimeStamp_s is '||v_TimeStamp_s);
    --dbms_output.put_line('v_TimeStamp_e is '||v_TimeStamp_e);

    OPEN lv_c2 FOR select file_type from wm_file_control;
     LOOP
     FETCH lv_c2 INTO v_Filetype;
     EXIT WHEN lv_c2%NOTFOUND;

     v_Filetype    := trim(v_Filetype);

     -- Get File Info
     SELECT entity_id, file_type_id
     INTO  v_Entity_ID, v_Filetype_ID
     FROM wm_file_control
     WHERE file_type = v_Filetype;

     -- Assign traffic table by filetype
     case
       when v_Filetype = 'DFE'
	 then v_traffic_table := 'LU_TF_QCHAT_DFE_TAB';
       when v_Filetype = 'HAD'
	 then v_traffic_table := 'LU_TF_QCHAT_HAD_TAB';
       when v_Filetype = 'ESM_Core_IF'
	 then v_traffic_table := 'LU_TF_QCHAT_ESMQ_CORE_IF_TAB';
       when v_Filetype = 'CCD'
	 then v_traffic_table := 'LU_TF_QCHAT_CCD_TAB';
       when v_Filetype = 'CID'
	 then v_traffic_table := 'LU_TF_QCHAT_CID_TAB';
       when v_Filetype = 'CRH'
	 then v_traffic_table := 'LU_TF_QCHAT_CRH_TAB';
       when v_Filetype = 'DCH'
	 then v_traffic_table := 'LU_TF_QCHAT_DCH_TAB';
       when v_Filetype = 'ESM_Regional_IF'
	 then v_traffic_table := 'LU_TF_QCHAT_ESM_REGION_IF_TAB';
       when v_Filetype = 'GCF'
	 then v_traffic_table := 'LU_TF_QCHAT_GCF_TAB';
       when v_Filetype = 'GCH'
	 then v_traffic_table := 'LU_TF_QCHAT_GCH_TAB';
       when v_Filetype = 'GCM'
	 then v_traffic_table := 'LU_TF_QCHAT_GCM_TAB';
       when v_Filetype = 'GMH'
	 then v_traffic_table := 'LU_TF_QCHAT_GMH_TAB';
       when v_Filetype = 'GSR'
	 then v_traffic_table := 'LU_TF_QCHAT_GSR_TAB';
       when v_Filetype = 'MCH'
	 then v_traffic_table := 'LU_TF_QCHAT_MCH_TAB';
       when v_Filetype = 'RGA'
	 then v_traffic_table := 'LU_TF_QCHAT_RGA_TAB';
       when v_Filetype = 'RMM'
	 then v_traffic_table := 'LU_TF_QCHAT_RMM_TAB';
       when v_Filetype = 'RULS'
	 then v_traffic_table := 'LU_TF_QCHAT_RULS_TAB';
     end case; 

    -- Count existed rows in traffic table
    v_SelectTF  := ' Select count(*) from ' || v_traffic_table 
		|| ' WHERE TSTAMP between ' || '''' || v_TimeStamp_s || ''''  
		|| ' and ' || '''' || v_TimeStamp_e || '''' ;
    --dbms_output.put_line(v_SelectTF);
    EXECUTE IMMEDIATE v_SelectTF INTO v_count_tf; 

    v_SelectDA  := ' Select count(*) from wm_available_data da '
		|| ' WHERE EXISTS (SELECT tf.instance_id from ' 
		|| v_traffic_table 
		|| ' tf WHERE tf.instance_id = da.instance_id and '
		|| ' tf.TSTAMP = da.TIMESTAMP and '
		|| ' tf.TSTAMP between ' || '''' || v_TimeStamp_s || ''''
		|| ' and ' ||  '''' || v_TimeStamp_e || '''' || ' )';
    --dbms_output.put_line(v_SelectDA);
    EXECUTE IMMEDIATE v_SelectDA INTO v_count_da;
   
    -- Merge traffic table data into data availability data

    v_MergeStmt := ' MERGE INTO wm_available_data da USING ' 
		|| ' (Select TSTAMP, INSTANCE_ID from ' || v_traffic_table
		|| ' WHERE TSTAMP between ' || '''' || v_TimeStamp_s || ''''
		|| ' and ' ||  '''' || v_TimeStamp_e || '''' || ' ) '
		|| ' tf ON (da.INSTANCE_ID = tf.INSTANCE_ID AND '
		|| ' da.TIMESTAMP = tf.TSTAMP ) '
                || ' WHEN MATCHED THEN '
   	        || ' UPDATE SET da.event_id = da.event_id '
		|| ' WHEN NOT MATCHED THEN '
	        || ' INSERT (TIMESTAMP, INSTANCE_ID, ENTITY_ID, FILE_TYPE_ID, '
	        || ' HOUR, EVENT_ID) VALUES (tf.TSTAMP, tf.INSTANCE_ID, ''' 
	        || v_Entity_ID || ''', ''' || v_Filetype_ID 
	        || ''' , floor((((to_char(tf.TSTAMP,''HH24'')* ' || gTimeUnit 
	        || ' ) + to_char(tf.TSTAMP,''MI''))* ' || gTimeSlice || ' )/(24* ' 
	        || gTimeUnit || ' )), patchMissingDA.insert_event(tf.TSTAMP, '
	        || ' tf.INSTANCE_ID, ''' || v_Entity_ID || ''', ''' || v_Filetype || '''))';
    EXECUTE IMMEDIATE v_MergeStmt;
    commit;

    v_count_update := v_count_tf - v_count_da;
    dbms_output.put_line('Merge with ' || v_traffic_table || ' :');
    dbms_output.put_line(v_count_update || ' rows has been successfully insert into DA  ');
    dbms_output.put_line(v_count_da || ' rows has been successfully updated in DA ' || CHR(10));

    END LOOP;
    CLOSE lv_c2;

END;
/

show errors;

DROP PACKAGE patchMissingDA;

EXIT;
